﻿using PureMVC.Patterns;
using PureMVC.Interfaces;
using WinFormTest.Controller;

namespace WinFormTest
{
	public class ApplicationFacade : Facade
	{
		#region Notification name constants

		public const string STARTUP					= "startup";
		
		public const string NEW_USER		 		= "newUser";
		public const string USER_ADDED				= "userAdded";

		#endregion

		#region Accessors

		/// <summary>
		/// Facade Singleton Factory method.  This method is thread safe.
		/// </summary>
		public new static IFacade Instance
		{
			get
			{
				if (m_instance == null)
				{
					lock (m_staticSyncRoot)
					{
						if (m_instance == null) m_instance = new ApplicationFacade();
					}
				}

				return m_instance;
			}
		}

		#endregion

		#region Public methods

		/// <summary>
		/// Start the application
		/// </summary>
		/// <param name="app"></param>
		public void Startup(object app)
		{
			SendNotification(STARTUP, app);
		}

		#endregion

		#region Protected & Internal Methods

		protected ApplicationFacade()
		{
			// Protected constructor.
		}

		/// <summary>
		/// Explicit static constructor to tell C# compiler 
		/// not to mark type as beforefieldinit
		///</summary>
		static ApplicationFacade()
		{
		}

		/// <summary>
		/// Register Commands with the Controller
		/// </summary>
		protected override void InitializeController()
		{
			base.InitializeController();
            RegisterCommand(STARTUP, typeof(StartupCommand));
            //RegisterCommand(DELETE_USER, typeof(DeleteUserCommand));
            //RegisterCommand(ADD_ROLE_RESULT, typeof(AddRoleResultCommand));
		}

		#endregion
	}
}